@@ -1,3 +1,8 @@
+export const GLOBAL_EXCLUDE_TABLES = [
+  // internal migration tables
+  'public.SequelizeMeta',
+];
+
 export const NON_SYNCING_TABLES = [
   'logs.debug_logs',
   'logs.fhir_writes',
@@ -6,7 +11,6 @@ export const NON_SYNCING_TABLES = [
   'public.one_time_logins',
   'public.patient_vrs_data',
   'public.refresh_tokens',
-  'public.SequelizeMeta',
   'public.signers',
   'public.sync_device_ticks',
   'public.sync_lookup_ticks',
@@ -19,7 +23,9 @@ export const NON_SYNCING_TABLES = [
 
 export const NON_LOGGED_TABLES = [
   // logs
-  'logs.*',
+  'logs.changes',
+  'logs.accesses',
+  'logs.debug_logs',
 
   // internal authentication tables
   'public.one_time_logins',
@@ -32,9 +38,6 @@ export const NON_LOGGED_TABLES = [
   'public.sync_device_ticks',
   'public.sync_lookup_ticks',
 
-  // internal migration tables
-  'public.SequelizeMeta',
-
   // caches
   'public.user_localisation_caches',
   'public.user_recently_viewed_patients',
